@@ -1,7 +1,5 @@
 package Monitoring::Spooler::Web;
-{
-  $Monitoring::Spooler::Web::VERSION = '0.04';
-}
+$Monitoring::Spooler::Web::VERSION = '0.05';
 BEGIN {
   $Monitoring::Spooler::Web::AUTHORITY = 'cpan:TEX';
 }
@@ -120,6 +118,9 @@ sub _filter_params {
     # add the remote_addr
     $request_ref->{'remote_addr'} = $request->address();
 
+    # add the path
+    $request_ref->{'path'} = $request->path_info;
+
     return $request_ref;
 }
 
